==> apache-dolphinscheduler-3.1.9-src.tar.gz: apache-dolphinscheduler-3.1.9-src/dolphinscheduler-ui/src/locales/zh_CN/resource.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  file: {
    file_manage: '文件管理',
    create_folder: '创建文件夹',
    create_file: '创建文件',
    upload_files: '上传文件',
    enter_keyword_tips: '请输入关键词',
    name: '名称',
    user_name: '所属用户',
    whether_directory: '是否文件夹',
    file_name: '文件名称',
    description: '描述',
    size: '大小',
    update_time: '更新时间',
    operation: '操作',
    edit: '编辑',
    rename: '重命名',
    download: '下载',
    delete: '删除',
    yes: '是',
    no: '否',
    folder_name: '文件夹名称',
    enter_name_tips: '请输入名称',
    enter_description_tips: '请输入描述',
    enter_content_tips: '请输入资源内容',
    enter_suffix_tips: '请输入文件后缀',
    duplicate_suffix_tips: '文件后缀重复',
    file_format: '文件格式',
    file_content: '文件内容',
    delete_confirm: '确定删除吗?',
    confirm: '确定',
    cancel: '取消',
    success: '成功',
    file_details: '文件详情',
    return: '返回',
    save: '保存'
  },
  udf: {
    udf_resources: 'UDF资源',
    create_folder: '创建文件夹',
    upload_udf_resources: '上传UDF资源',
    udf_source_name: 'UDF资源名称',
    user_name: '所属用户',
    whether_directory: '是否文件夹',
    file_name: '文件名称',
    file_size: '文件大小',
    description: '描述',
    create_time: '创建时间',
    update_time: '更新时间',
    operation: '操作',
    yes: '是',
    no: '否',
    edit: '编辑',
    download: '下载',
    delete: '删除',
    success: '成功',
    folder_name: '文件夹名称',
    upload: '上传',
    upload_files: '上传文件',
    file_upload: '文件上传',
    delete_confirm: '确定删除吗?',
    enter_keyword_tips: '请输入关键词',
    enter_name_tips: '请输入名称',
    enter_description_tips: '请输入描述'
  },
  function: {
    udf_function: 'UDF函数',
    create_udf_function: '创建UDF函数',
    edit_udf_function: '编辑UDF函数',
    udf_function_name: 'UDF函数名称',
    user_name: '所属用户',
    class_name: '类名',
    type: '类型',
    description: '描述',
    jar_package: 'jar包',
    update_time: '更新时间',
    operation: '操作',
    rename: '重命名',
    edit: '编辑',
    delete: '删除',
    success: '成功',
    package_name: '包名类名',
    udf_resources: 'UDF资源',
    instructions: '使用说明',
    upload_resources: '上传资源',
    udf_resources_directory: 'UDF资源目录',
    delete_confirm: '确定删除吗?',
    enter_keyword_tips: '请输入关键词',
    enter_udf_unction_name_tips: '请输入UDF函数名称',
    enter_package_name_tips: '请输入包名类名',
    enter_select_udf_resources_tips: '请选择UDF资源',
    enter_select_udf_resources_directory_tips: '请选择UDF资源目录',
    enter_instructions_tips: '请输入使用说明',
    enter_name_tips: '请输入名称',
    enter_description_tips: '请输入描述',
    upload: '上传',
    upload_udf_resources: '上传UDF资源'
  },
  task_group_option: {
    manage: '任务组管理',
    option: '任务组配置',
    create: '创建任务组',
    edit: '编辑任务组',
    delete: '删除任务组',
    view_queue: '查看任务组队列',
    switch_status: '切换任务组状态',
    code: '任务组编号',
    name: '任务组名称',
    project_name: '项目名称',
    resource_pool_size: '资源容量',
    resource_used_pool_size: '已用资源',
    desc: '描述信息',
    status: '任务组状态',
    enable_status: '启用',
    disable_status: '不可用',
    please_enter_name: '请输入任务组名称',
    please_enter_desc: '请输入任务组描述',
    please_enter_resource_pool_size: '请输入资源容量大小',
    positive_integer_tips: '应为正整数',
    please_select_project: '请选择项目',
    create_time: '创建时间',
    update_time: '更新时间',
    actions: '操作',
    please_enter_keywords: '请输入搜索关键词'
  },
  task_group_queue: {
    actions: '操作',
    task_name: '任务名称',
    task_group_name: '任务组名称',
    project_name: '项目名称',
    task_instance_name: '任务实例',
    workflow_instance_name: '工作流实例',
    queue: '任务组队列',
    priority: '组内优先级',
    priority_be_a_number: '优先级必须是大于等于0的数值',
    force_starting_status: '是否强制启动',
    in_queue: '是否排队中',
    task_status: '任务状态',
    view_task_group_queue: '查看任务组队列',
    the_status_of_waiting: '等待入队',
    the_status_of_queuing: '排队中',
    the_status_of_releasing: '已释放',
    modify_priority: '修改优先级',
    start_task: '强制启动',
    priority_not_empty: '优先级不能为空',
    priority_must_be_number: '优先级必须是数值',
    please_select_task_name: '请选择节点名称',
    create_time: '创建时间',
    update_time: '更新时间',
    edit_priority: '修改优先级'
  }
}

==> apache-dolphinscheduler-3.2.0-src.tar.gz: apache-dolphinscheduler-3.2.0-src/dolphinscheduler-ui/src/locales/zh_CN/resource.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  file: {
    file_manage: '文件管理',
    create_folder: '创建文件夹',
    create_file: '创建文件',
    upload_files: '上传文件',
    enter_keyword_tips: '请输入关键词',
    name: '名称',
    user_name: '所属用户',
    tenant_name: '所属租户',
    whether_directory: '是否文件夹',
    file_name: '文件名称',
    description: '描述',
    size: '大小',
    create_time: '创建时间',
    update_time: '更新时间',
    operation: '操作',
    edit: '编辑',
    reupload: '重新上传文件',
    rename: '重命名',
    download: '下载',
    delete: '删除',
    yes: '是',
    no: '否',
    folder_name: '文件夹名称',
    enter_name_tips: '请输入名称',
    enter_description_tips: '请输入描述',
    enter_content_tips: '请输入资源内容',
    enter_suffix_tips: '请输入文件后缀',
    duplicate_suffix_tips: '文件后缀重复',
    file_format: '文件格式',
    file_content: '文件内容',
    delete_confirm: '确定删除吗?',
    confirm: '确定',
    cancel: '取消',
    success: '成功',
    file_details: '文件详情',
    return: '返回',
    save: '保存'
  },
  udf: {
    udf_resources: 'UDF资源',
    upload_udf_resources: '上传UDF资源',
    udf_source_name: 'UDF资源名称'
  },
  function: {
    udf_function: 'UDF函数',
    create_udf_function: '创建UDF函数',
    edit_udf_function: '编辑UDF函数',
    udf_function_name: 'UDF函数名称',
    user_name: '所属用户',
    class_name: '类名',
    type: '类型',
    description: '描述',
    jar_package: 'jar包',
    update_time: '更新时间',
    operation: '操作',
    rename: '重命名',
    edit: '编辑',
    delete: '删除',
    success: '成功',
    package_name: '包名类名',
    udf_resources: 'UDF资源',
    instructions: '使用说明',
    upload_resources: '上传资源',
    udf_resources_directory: 'UDF资源目录',
    delete_confirm: '确定删除吗?',
    enter_keyword_tips: '请输入关键词',
    enter_udf_unction_name_tips: '请输入UDF函数名称',
    enter_package_name_tips: '请输入包名类名',
    enter_select_udf_resources_tips: '请选择UDF资源',
    enter_select_udf_resources_directory_tips: '请选择UDF资源目录',
    enter_instructions_tips: '请输入使用说明',
    enter_name_tips: '请输入名称',
    enter_description_tips: '请输入描述',
    upload: '上传',
    upload_udf_resources: '上传UDF资源'
  },
  task_group_option: {
    manage: '任务组管理',
    option: '任务组配置',
    create: '创建任务组',
    edit: '编辑任务组',
    delete: '删除任务组',
    view_queue: '查看任务组队列',
    switch_status: '切换任务组状态',
    code: '任务组编号',
    name: '任务组名称',
    project_name: '项目名称',
    resource_pool_size: '资源容量',
    resource_used_pool_size: '已用资源',
    desc: '描述信息',
    status: '任务组状态',
    enable_status: '启用',
    disable_status: '不可用',
    please_enter_name: '请输入任务组名称',
    please_enter_desc: '请输入任务组描述',
    please_enter_resource_pool_size: '请输入资源容量大小',
    positive_integer_tips: '应为正整数',
    please_select_project: '请选择项目',
    create_time: '创建时间',
    update_time: '更新时间',
    actions: '操作',
    please_enter_keywords: '请输入搜索关键词'
  },
  task_group_queue: {
    actions: '操作',
    task_name: '任务名称',
    task_group_name: '任务组名称',
    project_name: '项目名称',
    task_instance_name: '任务实例',
    workflow_instance_name: '工作流实例',
    queue: '任务组队列',
    priority: '组内优先级',
    priority_be_a_number: '优先级必须是大于等于0的数值',
    force_starting_status: '是否强制启动',
    in_queue: '是否排队中',
    task_status: '任务状态',
    view_task_group_queue: '查看任务组队列',
    the_status_of_waiting: '等待入队',
    the_status_of_queuing: '排队中',
    the_status_of_releasing: '已释放',
    modify_priority: '修改优先级',
    start_task: '强制启动',
    priority_not_empty: '优先级不能为空',
    priority_must_be_number: '优先级必须是数值',
    please_select_task_name: '请选择节点名称',
    create_time: '创建时间',
    update_time: '更新时间',
    edit_priority: '修改优先级'
  }
}
